@@ -30,6 +30,9 @@ This is the type handler that makes a schema available as type in other
 schemas. What this basically does is that you can reuse a schema in other
 schemas.
 
+Implementation-wise, this is the only type not deriving from
+L<Data::Schema::Type::Base>.
+
 To load schemas, either from a hash or YAML files, see
 L<Data::Schema::Plugin::LoadSchema::Hash> or
 L<Data::Schema::Plugin::LoadSchema::YAMLFile>.
@@ -60,7 +63,7 @@ sub handle_type {
 
     # push errors & warnings
     for (@$warnings) {
-        if (@{ $ds->warnings } >= $ds->config->{max_warnings}) {
+        if (@{ $ds->warnings } >= $ds->config->max_warnings) {
             $ds->too_many_warnings(1);
             last;
         }
@@ -68,7 +71,7 @@ sub handle_type {
             [[@{$ds->data_pos}, @{$_->[0]}], [@{$ds->schema_pos}, @{$_->[1]}], $_->[2]];
     }
     for (@$errors) {
-        if (@{ $ds->errors } >= $ds->config->{max_errors}) {
+        if (@{ $ds->errors } >= $ds->config->max_errors) {
             $ds->too_many_errors(1);
             last;
         }
